@@ -400,7 +400,7 @@ static json_t * database_client_get(const char * client_id, void * cls, int prof
 static char * get_password_clause_write(struct mod_parameters * param, const char * password) {
   char * clause = NULL, * password_encoded, digest[1024] = {0};
   
-  if (!o_strlen(password)) {
+  if (o_strnullempty(password)) {
     clause = o_strdup("''");
   } else if (param->conn->type == HOEL_DB_TYPE_SQLITE) {
     if (generate_digest_pbkdf2(password, param->PBKDF2_iterations, NULL, digest)) {
@@ -453,7 +453,7 @@ static char * get_salt_from_password_hash(struct mod_parameters * param, const c
   res = h_select(param->conn, j_query, &j_result, NULL);
   json_decref(j_query);
   if (res == H_OK) {
-    if (json_array_size(j_result) && json_string_length(json_object_get(json_array_get(j_result, 0), "gc_password"))) {
+    if (json_array_size(j_result) && !json_string_null_or_empty(json_object_get(json_array_get(j_result, 0), "gc_password"))) {
       if ((str_iterator = o_strchr(json_string_value(json_object_get(json_array_get(j_result, 0), "gc_password")), G_PBKDF2_ITERATOR_SEP)) != NULL) {
         gc_password_len = o_strchr(json_string_value(json_object_get(json_array_get(j_result, 0), "gc_password")), G_PBKDF2_ITERATOR_SEP) - json_string_value(json_object_get(json_array_get(j_result, 0), "gc_password"));
         *iterations = (unsigned int)strtol(str_iterator+1, NULL, 10);
@@ -809,7 +809,7 @@ size_t client_module_count_total(struct config_module * config, const char * pat
                       G_TABLE_CLIENT,
                       "columns",
                         "count(gc_id) AS total");
-  if (o_strlen(pattern)) {
+  if (!o_strnullempty(pattern)) {
     pattern_clause = get_pattern_clause(param, pattern);
     json_object_set_new(j_query, "where", json_pack("{s{ssss}}", "gc_id", "operator", "raw", "value", pattern_clause));
     o_free(pattern_clause);
@@ -849,7 +849,7 @@ json_t * client_module_get_list(struct config_module * config, const char * patt
                       limit,
                       "order_by",
                       "gc_client_id");
-  if (o_strlen(pattern)) {
+  if (!o_strnullempty(pattern)) {
     pattern_clause = get_pattern_clause(param, pattern);
     json_object_set_new(j_query, "where", json_pack("{s{ssss}}", "gc_id", "operator", "raw", "value", pattern_clause));
     o_free(pattern_clause);
@@ -920,7 +920,7 @@ json_t * client_module_is_valid(struct config_module * config, const char * clie
           json_array_append_new(j_result, json_string("scope must be a JSON array of string"));
         } else {
           json_array_foreach(json_object_get(j_client, "scope"), index, j_element) {
-            if (!json_is_string(j_element) || !json_string_length(j_element)) {
+            if (!json_is_string(j_element) || json_string_null_or_empty(j_element)) {
               json_array_append_new(j_result, json_string("scope must be a JSON array of string"));
             }
           }
