@@ -28,7 +28,7 @@
 #ifndef __GLEWLWYD_H_
 #define __GLEWLWYD_H_
 
-#define _GLEWLWYD_VERSION_ "2.6.1"
+#define _GLEWLWYD_VERSION_ "2.7.0"
 
 #include <jansson.h>
 
@@ -75,6 +75,8 @@
 #define GLEWLWYD_API_KEY_HEADER_KEY                        "Authorization"
 #define GLEWLWYD_API_KEY_HEADER_PREFIX                     "token "
 #define GLEWLWYD_API_KEY_LENGTH                            32
+#define GLEWLWYD_MAIL_ON_CONNEXION_TYPE                    "mail-on-connexion"
+#define GLEWLWYD_IP_GEOLOCATION_API_TYPE                   "ip-geolocation-api"
 
 #define GLEWLWYD_RUNNING     0
 #define GLEWLWYD_STOP        1
@@ -93,6 +95,7 @@
 #define GLEWLWYD_TABLE_SCOPE_GROUP_AUTH_SCHEME_MODULE_INSTANCE "g_scope_group_auth_scheme_module_instance"
 #define GLEWLWYD_TABLE_CLIENT_USER_SCOPE                       "g_client_user_scope"
 #define GLEWLWYD_TABLE_API_KEY                                 "g_api_key"
+#define GLEWLWYD_TABLE_MISC_CONFIG                             "g_misc_config"
 
 // Module management
 #define GLEWLWYD_MODULE_ACTION_STOP  0
@@ -170,6 +173,7 @@ struct _user_auth_scheme_module_instance * get_user_auth_scheme_module_instance(
 struct _user_auth_scheme_module * get_user_auth_scheme_module_lib(struct config_elements * config, const char * name);
 struct _plugin_module_instance * get_plugin_module_instance(struct config_elements * config, const char * name);
 struct _plugin_module * get_plugin_module_lib(struct config_elements * config, const char * name);
+char * get_ip_data(struct config_elements * config, const char * ip_address);
 
 // Modules generic functions
 int module_parameters_check(const char * module_parameters);
@@ -185,7 +189,7 @@ json_t * auth_trigger_user_scheme(struct config_elements * config, const char *
 json_t * auth_trigger_identify_scheme(struct config_elements * config, const char * scheme_type, const char * scheme_name, json_t * j_trigger_parameters, const struct _u_request * request);
 
 // Session
-int user_session_update(struct config_elements * config, const char * session_uid, const char * user_agent, const char * issued_for, const char * username, const char * scheme_name, int update_login);
+int user_session_update(struct config_elements * config, const char * session_uid, const char * ip_source, const char * user_agent, const char * issued_for, const char * username, const char * scheme_name, int update_login);
 json_t * get_session_for_username(struct config_elements * config, const char * session_uid, const char * username);
 json_t * get_current_user_for_session(struct config_elements * config, const char * session_uid);
 json_t * get_users_for_session(struct config_elements * config, const char * session_uid);
@@ -292,6 +296,7 @@ time_t glewlwyd_callback_get_session_age(struct config_plugin * config, const st
 char * glewlwyd_callback_get_login_url(struct config_plugin * config, const char * client_id, const char * scope_list, const char * callback_url, struct _u_map * additional_parameters);
 char * glewlwyd_callback_get_plugin_external_url(struct config_plugin * config, const char * name);
 char * glewlwyd_callback_generate_hash(struct config_plugin * config, const char * data);
+void glewlwyd_callback_update_issued_for(struct config_plugin * config, const struct _h_connection * conn, const char * sql_table, const char * issued_for_column, const char * issued_for_value, const char * id_column, json_int_t id_value);
 json_t * glewlwyd_plugin_callback_get_user_list(struct config_plugin * config, const char * pattern, size_t offset, size_t limit);
 json_t * glewlwyd_plugin_callback_get_user(struct config_plugin * config, const char * username);
 json_t * glewlwyd_plugin_callback_get_user_profile(struct config_plugin * config, const char * username);
@@ -330,6 +335,7 @@ json_t * glewlwyd_module_callback_check_user_session(struct config_module * conf
 int glewlwyd_module_metrics_increment_counter(struct config_module * config, const char * metrics_name, size_t inc, const char * module_type, const char * module_name);
 int glewlwyd_module_callback_metrics_add_metric(struct config_module * config, const char * name, const char * help);
 int glewlwyd_module_callback_metrics_increment_counter(struct config_module * config, const char * name, size_t inc, ...);
+void glewlwyd_module_callback_update_issued_for(struct config_module * config, const struct _h_connection * conn, const char * sql_table, const char * issued_for_column, const char * issued_for_value, const char * id_column, json_int_t id_value);
 
 // Client CRUD functions
 json_t * get_client_list(struct config_elements * config, const char * pattern, size_t offset, size_t limit, const char * source);
@@ -353,6 +359,15 @@ json_t * get_api_key_list(struct config_elements * config, const char * pattern,
 json_t * generate_api_key(struct config_elements * config, const char * username, const char * issued_for, const char * user_agent);
 int disable_api_key(struct config_elements * config, const char * token_hash);
 
+// Misc Config CRUD functions
+json_t * get_misc_config_list(struct config_elements * config);
+json_t * get_misc_config(struct config_elements * config, const char * type, const char * name);
+json_t * is_misc_config_valid(const char * name, json_t * j_misc_config);
+int add_misc_config(struct config_elements * config, const char * name, json_t * j_misc_config);
+int set_misc_config(struct config_elements * config, const char * name, json_t * j_misc_config);
+int delete_misc_config(struct config_elements * config, const char * name);
+void update_issued_for(struct config_elements * config, const struct _h_connection * conn, const char * sql_table, const char * issued_for_column, const char * issued_for_value, const char * id_column, json_int_t id_value);
+
 // Metrics functions
 void glewlwyd_metrics_close(struct config_elements * config);
 int glewlwyd_metrics_init(struct config_elements * config);
@@ -456,6 +471,11 @@ int callback_glewlwyd_get_api_key_list (const struct _u_request * request, struc
 int callback_glewlwyd_delete_api_key (const struct _u_request * request, struct _u_response * response, void * user_data);
 int callback_glewlwyd_add_api_key (const struct _u_request * request, struct _u_response * response, void * user_data);
 
+int callback_glewlwyd_get_misc_config_list (const struct _u_request * request, struct _u_response * response, void * user_data);
+int callback_glewlwyd_get_misc_config (const struct _u_request * request, struct _u_response * response, void * user_data);
+int callback_glewlwyd_set_misc_config (const struct _u_request * request, struct _u_response * response, void * user_data);
+int callback_glewlwyd_delete_misc_config (const struct _u_request * request, struct _u_response * response, void * user_data);
+
 int callback_metrics (const struct _u_request * request, struct _u_response * response, void * user_data);
 
 int callback_default (const struct _u_request * request, struct _u_response * response, void * user_data);
