@@ -90,7 +90,7 @@ json_t * glewlwyd_callback_check_session_valid(struct config_plugin * config, co
     j_user = get_current_user_for_session(config->glewlwyd_config, session_uid);
     // Check if session is valid
     if (check_result_value(j_user, G_OK)) {
-      if (o_strlen(scope_list)) {
+      if (!o_strnullempty(scope_list)) {
         // For all allowed scope, check that the current session has a valid session
         j_scope_allowed = get_validated_auth_scheme_list_from_scope_list(config->glewlwyd_config, scope_list, session_uid);
         if (check_result_value(j_scope_allowed, G_OK)) {
@@ -198,7 +198,7 @@ json_t * glewlwyd_callback_check_client_valid(struct config_plugin * config, con
     j_client = get_client(config->glewlwyd_config, client_id, NULL);
     if (check_result_value(j_client, G_OK) && json_object_get(json_object_get(j_client, "client"), "enabled") == json_true()) {
       if (password != NULL) {
-        if (json_string_length(json_object_get(json_object_get(j_client, "client"), "client_secret"))) {
+        if (!json_string_null_or_empty(json_object_get(json_object_get(j_client, "client"), "client_secret"))) {
           if (0 != o_strcmp(password, json_string_value(json_object_get(json_object_get(j_client, "client"), "client_secret")))) {
             password_checked = 0;
           }
@@ -454,6 +454,14 @@ char * glewlwyd_callback_generate_hash(struct config_plugin * config, const char
   return generate_hash(config->glewlwyd_config->hash_algorithm, data);
 }
 
+void glewlwyd_callback_update_issued_for(struct config_plugin * config, const struct _h_connection * conn, const char * sql_table, const char * issued_for_column, const char * issued_for_value, const char * id_column, json_int_t id_value) {
+  const struct _h_connection * cur_conn = conn;
+  
+  if (cur_conn == NULL) {
+    cur_conn = config->glewlwyd_config->conn;
+  }
+  update_issued_for(config->glewlwyd_config, cur_conn, sql_table, issued_for_column, issued_for_value, id_column, id_value);
+}
 json_t * glewlwyd_plugin_callback_get_user_list(struct config_plugin * config, const char * pattern, size_t offset, size_t limit) {
   return get_user_list(config->glewlwyd_config, pattern, offset, limit, NULL);
 }
@@ -549,7 +557,7 @@ int glewlwyd_plugin_callback_delete_client(struct config_plugin * config, const
 }
 
 json_t * glewlwyd_plugin_callback_get_scheme_module(struct config_plugin * config, const char * mod_name) {
-  if (o_strlen(mod_name)) {
+  if (!o_strnullempty(mod_name)) {
     return get_user_auth_scheme_module(config->glewlwyd_config, mod_name);
   } else {
     return json_pack("{si}", "result", G_ERROR_PARAM);
@@ -557,7 +565,7 @@ json_t * glewlwyd_plugin_callback_get_scheme_module(struct config_plugin * confi
 }
 
 json_t * glewlwyd_plugin_callback_get_scheme_list(struct config_plugin * config, const char * username) {
-  if (o_strlen(username)) {
+  if (!o_strnullempty(username)) {
     return get_scheme_list_for_user(config->glewlwyd_config, username);
   } else {
     return json_pack("{si}", "result", G_ERROR_PARAM);
@@ -621,7 +629,7 @@ int glewlwyd_plugin_callback_metrics_increment_counter(struct config_plugin * co
   char * label = NULL;
   int ret = G_OK;
 
-  if (config != NULL && o_strlen(name)) {
+  if (config != NULL && !o_strnullempty(name)) {
     va_start(vl, inc);
     label = glewlwyd_metrics_build_label(vl);
     va_end(vl);
