@@ -189,7 +189,7 @@ static json_t * is_scheme_parameters_valid(json_t * j_params) {
       } else if (json_object_get(j_params, "code-duration") == NULL) {
         json_object_set_new(j_params, "code-duration", json_integer(GLEWLWYD_SCHEME_CODE_DEFAULT_LENGTH));
       }
-      if (!json_string_length(json_object_get(j_params, "host"))) {
+      if (json_string_null_or_empty(json_object_get(j_params, "host"))) {
         json_array_append_new(j_errors, json_string("host is mandatory and must be a non empty string"));
       }
       if (json_object_get(j_params, "port") != NULL && (!json_is_integer(json_object_get(j_params, "port")) || json_integer_value(json_object_get(j_params, "port")) < 0 || json_integer_value(json_object_get(j_params, "port")) > 65535)) {
@@ -209,21 +209,21 @@ static json_t * is_scheme_parameters_valid(json_t * j_params) {
       if (json_object_get(j_params, "password") != NULL && !json_is_string(json_object_get(j_params, "password"))) {
         json_array_append_new(j_errors, json_string("password is optional and must be a string"));
       }
-      if (!json_string_length(json_object_get(j_params, "from"))) {
+      if (json_string_null_or_empty(json_object_get(j_params, "from"))) {
         json_array_append_new(j_errors, json_string("from is mandatory and must be a non empty string"));
       }
       if (json_object_get(j_params, "templates") == NULL) {
-        if (json_object_get(j_params, "subject") != NULL && !json_string_length(json_object_get(j_params, "subject"))) {
+        if (json_object_get(j_params, "subject") != NULL && json_string_null_or_empty(json_object_get(j_params, "subject"))) {
           json_array_append_new(j_errors, json_string("subject is mandatory and must be a non empty string"));
         }
-        if (json_object_get(j_params, "body-pattern") != NULL && !json_string_length(json_object_get(j_params, "body-pattern"))) {
+        if (json_object_get(j_params, "body-pattern") != NULL && json_string_null_or_empty(json_object_get(j_params, "body-pattern"))) {
           json_array_append_new(j_errors, json_string("body-pattern is mandatory and must be a non empty string"));
         }
       } else {
-        if (json_object_get(j_params, "content-type") != NULL && !json_string_length(json_object_get(j_params, "content-type"))) {
+        if (json_object_get(j_params, "content-type") != NULL && json_string_null_or_empty(json_object_get(j_params, "content-type"))) {
           json_array_append_new(j_errors, json_string("content-type is optional and must be a string"));
         }
-        if (!json_string_length(json_object_get(j_params, "user-lang-property"))) {
+        if (json_string_null_or_empty(json_object_get(j_params, "user-lang-property"))) {
           json_array_append_new(j_errors, json_string("user-lang-property is mandatory and must be a non empty string"));
         }
         if (!json_is_object(json_object_get(j_params, "templates"))) {
@@ -236,10 +236,10 @@ static json_t * is_scheme_parameters_valid(json_t * j_params) {
               if (!json_is_boolean(json_object_get(j_template, "defaultLang"))) {
                 json_array_append_new(j_errors, json_string("defaultLang is madatory in a template and must be a JSON object"));
               }
-              if (!json_string_length(json_object_get(j_template, "subject"))) {
+              if (json_string_null_or_empty(json_object_get(j_template, "subject"))) {
                 json_array_append_new(j_errors, json_string("subject is mandatory for default lang and must be a non empty string"));
               }
-              if (json_object_get(j_template, "body") != NULL && !json_string_length(json_object_get(j_template, "body"))) {
+              if (json_object_get(j_template, "body") != NULL && json_string_null_or_empty(json_object_get(j_template, "body"))) {
                 json_array_append_new(j_errors, json_string("body is mandatory for default lang and must be a non empty string"));
               }
               if (json_object_get(j_template, "defaultLang") == json_true()) {
@@ -567,13 +567,13 @@ json_t * user_auth_scheme_module_trigger(struct config_module * config, const st
                                            json_integer_value(json_object_get(j_param, "port")),
                                            json_object_get(j_param, "use-tls")==json_true()?1:0,
                                            json_object_get(j_param, "verify-certificate")==json_false()?0:1,
-                                           json_string_length(json_object_get(j_param, "user"))?json_string_value(json_object_get(j_param, "user")):NULL,
-                                           json_string_length(json_object_get(j_param, "password"))?json_string_value(json_object_get(j_param, "password")):NULL,
+                                           !json_string_null_or_empty(json_object_get(j_param, "user"))?json_string_value(json_object_get(j_param, "user")):NULL,
+                                           !json_string_null_or_empty(json_object_get(j_param, "password"))?json_string_value(json_object_get(j_param, "password")):NULL,
                                            json_string_value(json_object_get(j_param, "from")),
                                            json_string_value(json_object_get(json_object_get(j_user, "user"), "email")),
                                            NULL,
                                            NULL,
-                                           json_string_length(json_object_get(j_param, "content-type"))?json_string_value(json_object_get(j_param, "content-type")):"text/plain; charset=utf-8",
+                                           !json_string_null_or_empty(json_object_get(j_param, "content-type"))?json_string_value(json_object_get(j_param, "content-type")):"text/plain; charset=utf-8",
                                            get_template_property(j_param, json_object_get(j_user, "user"), "subject"),
                                            body) == G_OK) {
               y_log_message(Y_LOG_LEVEL_WARNING, "Security - Scheme email - code sent for username %s at IP Address %s", username, ip_source);
