@@ -26,6 +26,135 @@
  */
 #include "glewlwyd.h"
 
+static const char * get_template_property(json_t * j_params, const char * user_lang, const char * property_field) {
+  json_t * j_template = NULL;
+  const char * property = NULL, * property_default = NULL, * lang = NULL;
+  
+  if (json_object_get(j_params, "templates") == NULL) {
+    property = json_string_value(json_object_get(j_params, property_field));
+  } else {
+    json_object_foreach(json_object_get(j_params, "templates"), lang, j_template) {
+      if (0 == o_strcmp(user_lang, lang)) {
+        property = json_string_value(json_object_get(j_template, property_field));
+      }
+      if (json_object_get(j_template, "defaultLang") == json_true()) {
+        property_default = json_string_value(json_object_get(j_template, property_field));
+      }
+    }
+    if (property == NULL) {
+      property = property_default;
+    }
+  }
+  return property;
+}
+
+static char * complete_template(const char * template, ...) {
+  va_list vl;
+  const char * variable, * value;
+  char * to_return = NULL, * tmp;
+  
+  va_start(vl, template);
+  variable = va_arg(vl, const char *);
+  to_return = o_strdup(template);
+  for (; variable != NULL; variable = va_arg(vl, const char *)) {
+    value = va_arg(vl, const char *);
+    tmp = str_replace(to_return, variable, value);
+    o_free(to_return);
+    to_return = tmp;
+    tmp = NULL;
+  }
+  return to_return;
+}
+
+struct send_mail_struct {
+  struct config_elements * config;
+  char                   * username;
+  char                   * ip_address;
+};
+
+static void * thread_send_mail_on_new_connexion(void * args) {
+  struct send_mail_struct * send_mail = (struct send_mail_struct *)args;
+  json_t * j_misc_config = get_misc_config(send_mail->config, GLEWLWYD_MAIL_ON_CONNEXION_TYPE, NULL), * j_user;
+  char * body, * ip_data = NULL;
+  const char * lang, * email, * body_pattern;
+  
+  if (check_result_value(j_misc_config, G_OK) && json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "enabled") == json_true()) {
+    j_user = get_user(send_mail->config, send_mail->username, NULL);
+    if (check_result_value(j_user, G_OK) && !json_string_null_or_empty(json_object_get(json_object_get(j_user, "user"), "email"))) {
+      email = json_string_value(json_object_get(json_object_get(j_user, "user"), "email"));
+      // Send an e-mail to the user to notify a new connexion
+      y_log_message(Y_LOG_LEVEL_WARNING, "Security - New connexion - Notification sent to username %s, e-mail %s at IP Address %s", send_mail->username, email, send_mail->ip_address);
+      lang = json_string_value(json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "user-lang-property"));
+      body_pattern = get_template_property(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), lang, "body-pattern");
+      if (o_strstr(body_pattern, "{LOCATION}") != NULL) {
+        ip_data = get_ip_data(send_mail->config, send_mail->ip_address);
+        body = complete_template(body_pattern, "{USERNAME}", send_mail->username, "{IP}", send_mail->ip_address, "{LOCATION}", ip_data!=NULL?ip_data:"-", NULL);
+        o_free(ip_data);
+      } else {
+        body = complete_template(body_pattern, "{USERNAME}", send_mail->username, "{IP}", send_mail->ip_address, NULL);
+      }
+      if (body != NULL) {
+        if (ulfius_send_smtp_rich_email(json_string_value(json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "host")),
+                                       json_integer_value(json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "port")),
+                                       json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "use-tls")==json_true()?1:0,
+                                       json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "verify-certificate")==json_false()?0:1,
+                                       !json_string_null_or_empty(json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "user"))?json_string_value(json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "user")):NULL,
+                                       !json_string_null_or_empty(json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "password"))?json_string_value(json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "password")):NULL,
+                                       json_string_value(json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "from")),
+                                       email,
+                                       NULL,
+                                       NULL,
+                                       !json_string_null_or_empty(json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "content-type"))?json_string_value(json_object_get(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), "content-type")):"text/plain; charset=utf-8",
+                                       get_template_property(json_object_get(json_object_get(j_misc_config, "misc_config"), "value"), lang, "subject"),
+                                       body) != U_OK) {
+          y_log_message(Y_LOG_LEVEL_ERROR, "thread_send_mail_on_new_connexion - Error ulfius_send_smtp_rich_email");
+        }
+      } else {
+        y_log_message(Y_LOG_LEVEL_ERROR, "thread_send_mail_on_new_connexion - Error complete_template");
+      }
+      o_free(body);
+    }
+    json_decref(j_user);
+  }
+  o_free(send_mail->username);
+  o_free(send_mail->ip_address);
+  o_free(send_mail);
+  json_decref(j_misc_config);
+  
+  return NULL;
+}
+
+static void send_mail_on_new_connexion(struct config_elements * config, const char * username, const char * ip_address) {
+  struct send_mail_struct * send_mail = o_malloc(sizeof(struct send_mail_struct));
+  pthread_t thread_mail_connexion;
+  int thread_ret, thread_detach;
+  pthread_attr_t attr;
+  struct sched_param param;
+
+  if (send_mail != NULL) {
+    send_mail->config = config;
+    send_mail->username = o_strdup(username);
+    send_mail->ip_address = o_strdup(ip_address);
+    if (o_strchr(send_mail->ip_address, ',') != NULL) {
+      *o_strchr(send_mail->ip_address, ',') = '\0';
+    }
+    pthread_attr_init (&attr);
+    pthread_attr_getschedparam (&attr, &param);
+    param.sched_priority = 0;
+    pthread_attr_setschedparam (&attr, &param);
+    thread_ret = pthread_create(&thread_mail_connexion, &attr, thread_send_mail_on_new_connexion, (void *)send_mail);
+    thread_detach = pthread_detach(thread_mail_connexion);
+    if (thread_ret || thread_detach) {
+      y_log_message(Y_LOG_LEVEL_ERROR, "send_mail_on_new_connexion - Error thread");
+      o_free(send_mail->username);
+      o_free(send_mail->ip_address);
+      o_free(send_mail);
+    }
+  } else {
+    y_log_message(Y_LOG_LEVEL_ERROR, "send_mail_on_new_connexion - Error allocating resources for send_mail");
+  }
+}
+
 json_t * get_session_scheme(struct config_elements * config, json_int_t gus_id) {
   json_t * j_query, * j_result, * j_return;
   int res;
@@ -146,7 +275,7 @@ json_t * get_users_for_session(struct config_elements * config, const char * ses
   size_t index;
   char * expire_clause, * session_uid_hash;
 
-  if (session_uid != NULL && o_strlen(session_uid)) {
+  if (session_uid != NULL && !o_strnullempty(session_uid)) {
     if (config->conn->type==HOEL_DB_TYPE_MARIADB) {
       expire_clause = o_strdup("> NOW()");
     } else if (config->conn->type==HOEL_DB_TYPE_PGSQL) {
@@ -226,7 +355,7 @@ json_t * get_current_user_for_session(struct config_elements * config, const cha
   int res;
   char * expire_clause, * session_uid_hash;
 
-  if (o_strlen(session_uid)) {
+  if (!o_strnullempty(session_uid)) {
     if (config->conn->type==HOEL_DB_TYPE_MARIADB) {
       expire_clause = o_strdup("> NOW()");
     } else if (config->conn->type==HOEL_DB_TYPE_PGSQL) {
@@ -286,8 +415,8 @@ json_t * get_current_user_for_session(struct config_elements * config, const cha
   return j_return;
 }
 
-int user_session_update(struct config_elements * config, const char * session_uid, const char * user_agent, const char * issued_for, const char * username, const char * scheme_name, int update_login) {
-  json_t * j_query, * j_session = get_session_for_username(config, session_uid, username);
+int user_session_update(struct config_elements * config, const char * session_uid, const char * ip_source, const char * user_agent, const char * issued_for, const char * username, const char * scheme_name, int update_login) {
+  json_t * j_query, * j_session = get_session_for_username(config, session_uid, username), * j_last_index;
   struct _user_auth_scheme_module_instance * scheme_instance = NULL;
   int res, ret;
   time_t now;
@@ -309,50 +438,60 @@ int user_session_update(struct config_elements * config, const char * session_ui
       res = h_update(config->conn, j_query, NULL);
       json_decref(j_query);
       if (res == H_OK) {
-        // Create session for user if not exist
-        j_query = json_pack("{sss{sssssssssi}}",
-                            "table",
-                            GLEWLWYD_TABLE_USER_SESSION,
-                            "values",
-                              "gus_session_hash",
-                              session_uid_hash,
-                              "gus_username",
-                              username,
-                              "gus_user_agent",
-                              user_agent!=NULL?user_agent:"",
-                              "gus_issued_for",
-                              issued_for!=NULL?issued_for:"",
-                              "gus_current",
-                              1);
-        if (update_login) {
-          if (config->conn->type==HOEL_DB_TYPE_MARIADB) {
-            expiration_clause = msprintf("FROM_UNIXTIME(%u)", (now + config->session_expiration));
-          } else if (config->conn->type==HOEL_DB_TYPE_PGSQL) {
-            expiration_clause = msprintf("TO_TIMESTAMP(%u)", (now + config->session_expiration));
-          } else { // HOEL_DB_TYPE_SQLITE
-            expiration_clause = msprintf("%u", (now + config->session_expiration));
-          }
-          if (config->conn->type==HOEL_DB_TYPE_MARIADB) {
-            last_login_clause = msprintf("FROM_UNIXTIME(%u)", (now));
-          } else if (config->conn->type==HOEL_DB_TYPE_PGSQL) {
-            last_login_clause = msprintf("TO_TIMESTAMP(%u)", (now));
-          } else { // HOEL_DB_TYPE_SQLITE
-            last_login_clause = msprintf("%u", (now));
-          }
-          json_object_set_new(json_object_get(j_query, "values"), "gus_last_login", json_pack("{ss}", "raw", last_login_clause));
-          json_object_set_new(json_object_get(j_query, "values"), "gus_expiration", json_pack("{ss}", "raw", expiration_clause));
-          o_free(last_login_clause);
-          o_free(expiration_clause);
-        }
-        res = h_insert(config->conn, j_query, NULL);
-        json_decref(j_query);
-        json_decref(j_session);
-        if (res == H_OK) {
-          j_session = get_session_for_username(config, session_uid, username);
+        if (pthread_mutex_lock(&config->insert_lock)) {
+          y_log_message(Y_LOG_LEVEL_ERROR, "user_session_update - Error pthread_mutex_lock");
+          ret = G_ERROR;
         } else {
-          y_log_message(Y_LOG_LEVEL_ERROR, "user_session_update - Error h_insert session");
-          glewlwyd_metrics_increment_counter_va(config, GLWD_METRICS_DATABSE_ERROR, 1, NULL);
-          j_session = json_pack("{si}", "result", G_ERROR_DB);
+          // Create session for user if not exist
+          j_query = json_pack("{sss{sssssssssi}}",
+                              "table",
+                              GLEWLWYD_TABLE_USER_SESSION,
+                              "values",
+                                "gus_session_hash", session_uid_hash,
+                                "gus_username", username,
+                                "gus_user_agent", user_agent!=NULL?user_agent:"",
+                                "gus_issued_for", issued_for!=NULL?issued_for:"",
+                                "gus_current", 1);
+          if (update_login) {
+            if (config->conn->type==HOEL_DB_TYPE_MARIADB) {
+              expiration_clause = msprintf("FROM_UNIXTIME(%u)", (now + config->session_expiration));
+            } else if (config->conn->type==HOEL_DB_TYPE_PGSQL) {
+              expiration_clause = msprintf("TO_TIMESTAMP(%u)", (now + config->session_expiration));
+            } else { // HOEL_DB_TYPE_SQLITE
+              expiration_clause = msprintf("%u", (now + config->session_expiration));
+            }
+            if (config->conn->type==HOEL_DB_TYPE_MARIADB) {
+              last_login_clause = msprintf("FROM_UNIXTIME(%u)", (now));
+            } else if (config->conn->type==HOEL_DB_TYPE_PGSQL) {
+              last_login_clause = msprintf("TO_TIMESTAMP(%u)", (now));
+            } else { // HOEL_DB_TYPE_SQLITE
+              last_login_clause = msprintf("%u", (now));
+            }
+            json_object_set_new(json_object_get(j_query, "values"), "gus_last_login", json_pack("{ss}", "raw", last_login_clause));
+            json_object_set_new(json_object_get(j_query, "values"), "gus_expiration", json_pack("{ss}", "raw", expiration_clause));
+            o_free(last_login_clause);
+            o_free(expiration_clause);
+          }
+          res = h_insert(config->conn, j_query, NULL);
+          json_decref(j_query);
+          json_decref(j_session);
+          if (res == H_OK) {
+            if ((j_last_index = h_last_insert_id(config->conn)) != NULL) {
+              update_issued_for(config, NULL, GLEWLWYD_TABLE_USER_SESSION, "gus_issued_for", issued_for, "gus_id", json_integer_value(j_last_index));
+              send_mail_on_new_connexion(config, username, ip_source);
+              j_session = get_session_for_username(config, session_uid, username);
+            } else {
+              y_log_message(Y_LOG_LEVEL_ERROR, "user_session_update - Error j_last_index session");
+              glewlwyd_metrics_increment_counter_va(config, GLWD_METRICS_DATABSE_ERROR, 1, NULL);
+              j_session = json_pack("{si}", "result", G_ERROR_DB);
+            }
+            json_decref(j_last_index);
+          } else {
+            y_log_message(Y_LOG_LEVEL_ERROR, "user_session_update - Error h_insert session");
+            glewlwyd_metrics_increment_counter_va(config, GLWD_METRICS_DATABSE_ERROR, 1, NULL);
+            j_session = json_pack("{si}", "result", G_ERROR_DB);
+          }
+          pthread_mutex_unlock(&config->insert_lock);
         }
       } else {
         y_log_message(Y_LOG_LEVEL_ERROR, "user_session_update - Error h_update session (0)");
