@@ -312,7 +312,7 @@ json_t * get_user(struct config_elements * config, const char * username, const
   struct _user_middleware_module_instance * user_middleware_module;
   size_t index, i;
   
-  if (!o_strlen(username)) {
+  if (o_strnullempty(username)) {
     j_return = json_pack("{si}", "result", G_ERROR_PARAM);
   } else if (source != NULL) {
     user_module = get_user_module_instance(config, source);
@@ -935,6 +935,8 @@ int user_delete_profile(struct config_elements * config, const char * username)
       } else {
         if ((ret = user_module->module->user_module_delete(config->config_m, username, user_module->cls)) != G_OK) {
           y_log_message(Y_LOG_LEVEL_ERROR, "user_delete_profile - Error user_module_delete");
+        } else {
+          y_log_message(Y_LOG_LEVEL_INFO, "Event - User '%s' removed - user action", username);
         }
       }
       if (ret == G_OK && !(config->delete_profile & GLEWLWYD_PROFILE_DELETE_DISABLE_PROFILE)) {
@@ -1103,7 +1105,7 @@ int glewlwyd_module_callback_metrics_increment_counter(struct config_module * co
   char * label = NULL;
   int ret = G_OK;
 
-  if (config != NULL && o_strlen(name)) {
+  if (config != NULL && !o_strnullempty(name)) {
     va_start(vl, inc);
     label = glewlwyd_metrics_build_label(vl);
     va_end(vl);
@@ -1116,3 +1118,12 @@ int glewlwyd_module_callback_metrics_increment_counter(struct config_module * co
   }
   return ret;
 }
+
+void glewlwyd_module_callback_update_issued_for(struct config_module * config, const struct _h_connection * conn, const char * sql_table, const char * issued_for_column, const char * issued_for_value, const char * id_column, json_int_t id_value) {
+  const struct _h_connection * cur_conn = conn;
+  
+  if (cur_conn == NULL) {
+    cur_conn = config->conn;
+  }
+  update_issued_for(config->glewlwyd_config, cur_conn, sql_table, issued_for_column, issued_for_value, id_column, id_value);
+}
