@@ -392,7 +392,7 @@ static json_t * database_user_get(const char * username, void * cls, int profile
 static char * get_password_clause_write(struct mod_parameters * param, const char * password) {
   char * clause = NULL, * password_encoded, digest[1024] = {0};
   
-  if (!o_strlen(password)) {
+  if (o_strnullempty(password)) {
     clause = o_strdup("''");
   } else if (param->conn->type == HOEL_DB_TYPE_SQLITE) {
     if (generate_digest_pbkdf2(password, param->PBKDF2_iterations, NULL, digest)) {
@@ -472,7 +472,7 @@ static int update_password_list(struct mod_parameters * param, json_int_t gu_id,
                             G_TABLE_USER_PASSWORD,
                             "values");
         for (i=0; i<new_passwords_len; i++) {
-          if (o_strlen(new_passwords[i])) {
+          if (!o_strnullempty(new_passwords[i])) {
             clause_password = get_password_clause_write(param, new_passwords[i]);
             json_array_append_new(json_object_get(j_query, "values"), json_pack("{sIs{ss}}", "gu_id", gu_id, "guw_password", "raw", clause_password));
             o_free(clause_password);
@@ -544,7 +544,8 @@ static char ** get_salt_from_password_hash(struct mod_parameters * param, const
               gc_password_len = json_string_length(json_object_get(j_element, "guw_password"));
               json_array_append_new(j_iterations, json_integer(0));
             }
-            if (json_string_length(json_object_get(j_element, "guw_password")) && o_base64_decode((const unsigned char *)json_string_value(json_object_get(j_element, "guw_password")), gc_password_len, password_b64_decoded, &password_b64_decoded_len)) {
+            if (!json_string_null_or_empty(json_object_get(j_element, "guw_password")) && o_base64_decode((const unsigned char *)json_string_value(json_object_get(j_element, "guw_password")), gc_password_len, password_b64_decoded, &password_b64_decoded_len)) {
+              password_b64_decoded[password_b64_decoded_len] = '\0';
               if ((salt = o_strdup((const char *)password_b64_decoded + password_b64_decoded_len - GLEWLWYD_DEFAULT_SALT_LENGTH)) != NULL) {
                 salt_list[index] = salt;
               } else {
@@ -915,7 +916,7 @@ size_t user_module_count_total(struct config_module * config, const char * patte
                       G_TABLE_USER,
                       "columns",
                         "count(gu_id) AS total");
-  if (o_strlen(pattern)) {
+  if (!o_strnullempty(pattern)) {
     pattern_clause = get_pattern_clause(param, pattern);
     json_object_set_new(j_query, "where", json_pack("{s{ssss}}", "gu_id", "operator", "raw", "value", pattern_clause));
     o_free(pattern_clause);
@@ -954,7 +955,7 @@ json_t * user_module_get_list(struct config_module * config, const char * patter
                       limit,
                       "order_by",
                       "gu_username");
-  if (o_strlen(pattern)) {
+  if (!o_strnullempty(pattern)) {
     pattern_clause = get_pattern_clause(param, pattern);
     json_object_set_new(j_query, "where", json_pack("{s{ssss}}", "gu_id", "operator", "raw", "value", pattern_clause));
     o_free(pattern_clause);
@@ -1030,7 +1031,7 @@ json_t * user_module_is_valid(struct config_module * config, const char * userna
           json_array_append_new(j_result, json_string("scope must be a JSON array of string"));
         } else {
           json_array_foreach(json_object_get(j_user, "scope"), index, j_element) {
-            if (!json_is_string(j_element) || !json_string_length(j_element)) {
+            if (!json_is_string(j_element) || json_string_null_or_empty(j_element)) {
               json_array_append_new(j_result, json_string("scope must be a JSON array of string"));
             }
           }
@@ -1146,7 +1147,7 @@ int user_module_add(struct config_module * config, json_t * j_user, void * cls)
           }
         }
       } else {
-        if (json_string_length(json_object_get(j_user, "password"))) {
+        if (!json_string_null_or_empty(json_object_get(j_user, "password"))) {
           if ((passwords = o_malloc(sizeof(char *))) != NULL) {
             passwords[0] = json_string_value(json_object_get(j_user, "password"));
             ret = update_password_list(param, json_integer_value(j_gu_id), passwords, 1, 1);
@@ -1232,7 +1233,7 @@ int user_module_update(struct config_module * config, const char * username, jso
             }
           }
         } else {
-          if (json_string_length(json_object_get(j_user, "password"))) {
+          if (!json_string_null_or_empty(json_object_get(j_user, "password"))) {
             if ((passwords = o_malloc(sizeof(char *))) != NULL) {
               passwords[0] = json_string_value(json_object_get(j_user, "password"));
               ret = update_password_list(param, json_integer_value(json_object_get(json_array_get(j_result, 0), "gu_id")), passwords, 1, 0);
