@@ -202,7 +202,7 @@ json_t * user_module_init(struct config_module * config, int readonly, int multi
   
   if (json_object_get(j_parameters, "error") == NULL) {
     const char * prefix = "";
-    if (json_string_length(json_object_get(j_parameters, "username-prefix"))) {
+    if (!json_string_null_or_empty(json_object_get(j_parameters, "username-prefix"))) {
       prefix = json_string_value(json_object_get(j_parameters, "username-prefix"));
     }
     if (password == NULL) {
@@ -307,7 +307,7 @@ size_t user_module_count_total(struct config_module * config, const char * patte
   json_t * j_user = NULL;
   size_t index = 0, total;
 
-  if (o_strlen(pattern)) {
+  if (!o_strnullempty(pattern)) {
     total = 0;
     json_array_foreach(json_object_get((json_t *)cls, "list"), index, j_user) {
       if (json_has_str_pattern_case(j_user, pattern)) {
@@ -353,7 +353,7 @@ json_t * user_module_get_list(struct config_module * config, const char * patter
     password = (json_int_t)json_array_size(json_object_get((json_t *)cls, "password"));
   }
   if (limit) {
-    if (o_strlen(pattern)) {
+    if (!o_strnullempty(pattern)) {
       j_pattern_array = json_array();
       json_array_foreach(json_object_get((json_t *)cls, "list"), index, j_user) {
         if (json_has_str_pattern_case(j_user, pattern)) {
@@ -410,7 +410,7 @@ json_t * user_module_get(struct config_module * config, const char * username, v
   json_t * j_user = NULL, * j_new_user;
   size_t index = 0;
   
-  if (username != NULL && o_strlen(username)) {
+  if (username != NULL && !o_strnullempty(username)) {
     json_array_foreach(json_object_get((json_t *)cls, "list"), index, j_user) {
       if (0 == o_strcmp(username, json_string_value(json_object_get(j_user, "username")))) {
         j_new_user = json_deep_copy(j_user);
@@ -544,7 +544,7 @@ int user_module_add(struct config_module * config, json_t * j_user, void * cls)
         j_pwd_cur = json_array_get(json_object_get((json_t *)cls, "password"), index);
         j_pwd_next = json_array_get(json_object_get(j_user, "password"), index);
         
-        if (json_string_length(j_pwd_next)) {
+        if (!json_string_null_or_empty(j_pwd_next)) {
           json_array_append(j_password, j_pwd_next);
         } else if (j_pwd_cur != NULL && 0 == o_strcmp("", json_string_value(j_pwd_next))) {
           json_array_append(j_password, j_pwd_cur);
@@ -552,7 +552,7 @@ int user_module_add(struct config_module * config, json_t * j_user, void * cls)
       }
       json_object_set_new((json_t *)cls, "password", j_password);
     } else {
-      if (json_string_length(json_object_get(j_user, "password"))) {
+      if (!json_string_null_or_empty(json_object_get(j_user, "password"))) {
         json_object_set((json_t *)cls, "password", json_object_get(j_user, "password"));
       } else {
         json_object_set((json_t *)cls, "password", json_null());
@@ -595,7 +595,7 @@ int user_module_update(struct config_module * config, const char * username, jso
         j_pwd_cur = json_array_get(json_object_get((json_t *)cls, "password"), index);
         j_pwd_next = json_array_get(json_object_get(j_user, "password"), index);
         
-        if (json_string_length(j_pwd_next)) {
+        if (!json_string_null_or_empty(j_pwd_next)) {
           json_array_append(j_password, j_pwd_next);
         } else if (j_pwd_cur != NULL && 0 == o_strcmp("", json_string_value(j_pwd_next))) {
           json_array_append(j_password, j_pwd_cur);
@@ -603,7 +603,7 @@ int user_module_update(struct config_module * config, const char * username, jso
       }
       json_object_set_new((json_t *)cls, "password", j_password);
     } else {
-      if (json_string_length(json_object_get(j_user, "password"))) {
+      if (!json_string_null_or_empty(json_object_get(j_user, "password"))) {
         json_object_set((json_t *)cls, "password", json_object_get(j_user, "password"));
       } else {
         json_object_set((json_t *)cls, "password", json_null());
@@ -756,9 +756,9 @@ int user_module_update_password(struct config_module * config, const char * user
   if (json_is_array(json_object_get((json_t *)cls, "password"))) {
     j_password = json_array();
     for (index=0; index<new_passwords_len; index++) {
-      if (o_strlen(new_passwords[index])) {
+      if (!o_strnullempty(new_passwords[index])) {
         json_array_append_new(j_password, json_string(new_passwords[index]));
-      } else if (new_passwords[index] != NULL && json_string_length(json_array_get(json_object_get((json_t *)cls, "password"), index))) {
+      } else if (new_passwords[index] != NULL && !json_string_null_or_empty(json_array_get(json_object_get((json_t *)cls, "password"), index))) {
         json_array_append(j_password, json_array_get(json_object_get((json_t *)cls, "password"), index));
       }
     }
